@@ -23,8 +23,6 @@
 
 namespace KDevelop {
 class IDocumentationProvider;
-class Context;
-class ContextMenuExtension;
 class Declaration;
 
 /**
@@ -46,8 +44,6 @@ class KDEVPLATFORMINTERFACES_EXPORT IDocumentationController
         
         /** Show the documentation specified by @p doc. */
         virtual void showDocumentation(KSharedPtr< KDevelop::IDocumentation > doc)=0;
-        
-        virtual ContextMenuExtension contextMenuExtension( Context* context ) = 0;
 };
 
 }
