@@ -20,7 +20,6 @@
 #include "cvsproxy.h"
 #include "cvsjob.h"
 
-#include <vcs/vcsmapping.h>
 #include <vcs/vcslocation.h>
 
 #include "importmetadatawidget.h"
@@ -40,7 +39,8 @@ ImportDialog::~ImportDialog()
 
 void ImportDialog::accept()
 {
-    CvsJob *job = dynamic_cast<CvsJob*>( m_plugin->import(m_widget->mapping(), m_widget->message() ) );
+    KDevelop::VcsJob *job = m_plugin->import(m_widget->message(), m_widget->source(),
+                                                m_widget->destination());
     if (job) {
         connect(job, SIGNAL( result(KJob*) ),
                 this, SLOT( jobFinished(KJob*) ));
@@ -60,7 +60,7 @@ void ImportDialog::jobFinished(KJob * job)
 
     static QRegExp re_file("^[IN]\\s(.*)");
     bool error = false;
-    QStringList lines = cvsjob->output().split("\n");
+    QStringList lines = cvsjob->output().split('\n');
     foreach(const QString &line, lines) {
         if (line.isEmpty()) {
             // ignore empty lines
@@ -80,7 +80,7 @@ void ImportDialog::jobFinished(KJob * job)
 
     if (error) {
         KMessageBox::error(this,
-            i18n("Some errors occurred while importing") + m_url.path(),
+            i18n("Some errors occurred while importing") + m_url.toLocalFile(),
             i18n("Import Error"));
     } else {
         KDialog::accept();
