@@ -70,6 +70,9 @@ std::string*/
 #include <sublime/area.h>
 #include <interfaces/iprojectcontroller.h>
 #include "diffsettings.h"
+#include <interfaces/iplugincontroller.h>
+#include <interfaces/ipatchexporter.h>
+#include "standardpatchexport.h"
 
 using namespace KDevelop;
 
@@ -208,6 +211,23 @@ void PatchReviewToolView::showEditDialog() {
     
     m_editPatch.previousHunk->setIcon(KIcon("arrow-up"));
     m_editPatch.nextHunk->setIcon(KIcon("arrow-down"));
+    m_editPatch.cancelReview->setIcon(KIcon("dialog-cancel"));
+    m_editPatch.finishReview->setIcon(KIcon("dialog-ok"));
+    
+    QMenu* exportMenu = new QMenu(m_editPatch.exportReview);
+    StandardPatchExport* stdactions = new StandardPatchExport(m_plugin, this);
+    stdactions->addActions(exportMenu);
+    connect(exportMenu, SIGNAL(triggered(QAction*)), m_plugin, SLOT(exporterSelected(QAction*)));
+    
+    IPluginController* pluginManager = ICore::self()->pluginController();
+    foreach( IPlugin* p, pluginManager->allPluginsForExtension( "org.kdevelop.IPatchExporter" ) )
+    {
+        KPluginInfo info=pluginManager->pluginInfo(p);
+        QAction* action=exportMenu->addAction(KIcon(info.icon()), info.name());
+        action->setData(qVariantFromValue<QObject*>(p));
+    }
+    
+    m_editPatch.exportReview->setMenu(exportMenu);
     
     connect( m_editPatch.previousHunk, SIGNAL( clicked( bool ) ), this, SLOT( prevHunk() ) );
     connect( m_editPatch.nextHunk, SIGNAL( clicked( bool ) ), this, SLOT( nextHunk() ) );
@@ -471,6 +491,48 @@ KUrl PatchReviewToolView::urlForFileModel(const Diff2::DiffModel* model)
   return file;
 }
 
+static QString stateToString(KDevelop::VcsStatusInfo::State state)
+{
+    switch(state)
+    {
+      case KDevelop::VcsStatusInfo::ItemAdded:
+          return i18n("Added");
+      case KDevelop::VcsStatusInfo::ItemDeleted:
+          return i18n("Deleted");
+      case KDevelop::VcsStatusInfo::ItemHasConflicts:
+          return i18n("Has Conflicts");
+      case KDevelop::VcsStatusInfo::ItemModified:
+          return i18n("Modified");
+      case KDevelop::VcsStatusInfo::ItemUpToDate:
+          return i18n("Up To Date");
+      case KDevelop::VcsStatusInfo::ItemUnknown:
+      case KDevelop::VcsStatusInfo::ItemUserState:
+          return i18n("Unknown");
+    }
+    return i18nc("Unknown VCS file status, probably a backend error", "?");
+}
+
+static KIcon stateToIcon(KDevelop::VcsStatusInfo::State state)
+{
+    switch(state)
+    {
+      case KDevelop::VcsStatusInfo::ItemAdded:
+          return KIcon("vcs-added");
+      case KDevelop::VcsStatusInfo::ItemDeleted:
+          return KIcon("vcs-removed");
+      case KDevelop::VcsStatusInfo::ItemHasConflicts:
+          return KIcon("vcs-conflicting");
+      case KDevelop::VcsStatusInfo::ItemModified:
+          return KIcon("vcs-locally-modified");
+      case KDevelop::VcsStatusInfo::ItemUpToDate:
+          return KIcon("vcs-normal");
+      case KDevelop::VcsStatusInfo::ItemUnknown:
+      case KDevelop::VcsStatusInfo::ItemUserState:
+          return KIcon("unknown");
+    }
+    return KIcon("dialog-error");
+}
+
 void PatchReviewToolView::kompareModelChanged()
 {
     m_editPatch.filesList->clear();
@@ -479,7 +541,7 @@ void PatchReviewToolView::kompareModelChanged()
     if (!m_plugin->modelList())
         return;
 
-    QMap<KUrl, QString> additionalUrls = m_plugin->patch()->additionalSelectableFiles();
+    QMap<KUrl, KDevelop::VcsStatusInfo::State> additionalUrls = m_plugin->patch()->additionalSelectableFiles();
     
     const Diff2::DiffModelList* models = m_plugin->modelList()->models();
     if ( !models )
@@ -505,8 +567,10 @@ void PatchReviewToolView::kompareModelChanged()
         const QString filenameArgument = ICore::self()->projectController()->prettyFileName(file, KDevelop::IProjectController::FormatPlain);
 
         QString text;
-        if(additionalUrls.contains(file) && !additionalUrls[file].isEmpty()) {
-            text = i18np("%2 (1 hunk, %3)", "%2 (%1 hunks, %3)", cnt, filenameArgument, additionalUrls[file]);
+        if(additionalUrls.contains(file)) {
+            VcsStatusInfo::State state = additionalUrls[file];
+            text = i18np("%2 (1 hunk, %3)", "%2 (%1 hunks, %3)", cnt, filenameArgument, stateToString(state));
+            item->setIcon(0, stateToIcon(state));
         } else {
             text = i18np("%2 (1 hunk)", "%2, (%1 hunks)", cnt, filenameArgument);
         }
@@ -520,7 +584,7 @@ void PatchReviewToolView::kompareModelChanged()
     ///findProject() excludes some useless files like backups, so we can use that to sort those files to the back
     for(int withProject = 1; withProject >= 0; --withProject)
     {
-      for(QMap<KUrl, QString>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); ++it)
+      for(QMap<KUrl, KDevelop::VcsStatusInfo::State>::const_iterator it = additionalUrls.constBegin(); it != additionalUrls.constEnd(); ++it)
       {
         KUrl url = it.key();
         
@@ -534,14 +598,10 @@ void PatchReviewToolView::kompareModelChanged()
           QTreeWidgetItem* item = new QTreeWidgetItem(m_editPatch.filesList);
           
           m_editPatch.filesList->insertTopLevelItem(0, item);
-          QString text = ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain);
-          if(!(*it).isEmpty())
-            text += " (" + (*it) + ")";
           
-          item->setData( 0, Qt::DisplayRole, text );
-          QVariant v;
-          v.setValue<KUrl>( url );
-          item->setData( 0, Qt::UserRole, v );
+          item->setText(0, i18n("%1 (%2)", ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain), stateToString(it.value())));
+          item->setIcon(0, stateToIcon(it.value()));
+          item->setData( 0, Qt::UserRole, qVariantFromValue<KUrl>(url));
           item->setCheckState( 0, Qt::Unchecked );
         }
       }
@@ -1126,9 +1186,9 @@ void PatchReviewPlugin::updateKompareModel() {
 
         return;
     } catch ( const QString & str ) {
-        KMessageBox::error(0, str, "Kompare Model Update");
+        KMessageBox::error(0, str, i18n("Kompare Model Update"));
     } catch ( const char * str ) {
-        KMessageBox::error(0, str, "Kompare Model Update");
+        KMessageBox::error(0, str, i18n("Kompare Model Update"));
     }
     m_modelList.reset( 0 );
     m_kompareInfo.reset( 0 );
@@ -1384,6 +1444,17 @@ QWidget* PatchReviewPlugin::createToolView(QWidget* parent)
     return new PatchReviewToolView(parent, this);
 }
 
+void PatchReviewPlugin::exporterSelected(QAction* action)
+{
+    IPlugin* exporter = qobject_cast<IPlugin*>(action->data().value<QObject*>());
+    
+    if(exporter) {
+        qDebug() << "exporting patch" << exporter << action->text();
+        exporter->extension<IPatchExporter>()->exportPatch(patch());
+    }
+}
+
+
 #if 0
 void PatchReviewPlugin::determineState() {
     LocalPatchSourcePointer lpatch = m_patch;
