@@ -86,7 +86,9 @@ void CCPreferences::writeToSettings()
     settings.m_localColorizationLevel = preferencesDialog->kcfg_localColorization->value();
     settings.m_globalColorizationLevel = preferencesDialog->kcfg_globalColorization->value();
     settings.m_highlightSemanticProblems = preferencesDialog->kcfg_highlightSemanticProblems->isChecked();
+    settings.m_highlightProblematicLines = preferencesDialog->kcfg_highlightProblematicLines->isChecked();
     settings.m_showMultiLineInformation = preferencesDialog->kcfg_showMultiLineSelectionInformation->isChecked();
+    settings.m_minFilesForSimplifiedParsing = preferencesDialog->kcfg_minFilesForSimplifiedParsing->value();
     
     emit settings.emitChanged();
 }
